@@ -2,26 +2,13 @@
 
 /*
    Empty Trash - A Plugin for SqurrelMail
-   Version: 1.3
-   Version Date: 29-Jun-2004
+   Version: 1.4
+   Version Date: 12-Mar-2005
    Authors: Derek Battams <derek@battams.ca>
             Paul Lesneiwski <pdontthink@angrynerds.com>
 
    Please see the README file for further information
 
-   File: setup.php
-
-DATE          AUTHOR   CHANGE
-=============================================================================
-17-Apr-2002   ddb      Completion of original version
-03-Nov-2002   ddb      Bug fixes; audit for SM >= 1.2.8 compatibility
-04-Jul-2003   pl       New setup.php format for faster overall SM performance
-                       Updated for SM version reporting API
-29-Jun-2004   pl       Created config file to allow administrative control over
-                       deletion criteria.
-                       Fixed time-based criteria to measure days instead of weeks
-                       (which had an inadvertent bug)
-
 */
 
 
@@ -52,10 +39,11 @@ function do_delete_do()
 {
 global $data_dir, $username;
 
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/empty_trash/config.php');
-   else
-      include_once('../plugins/empty_trash/config.php');
+   include_once(SM_PATH . 'plugins/empty_trash/config.php');
+
+   $trash_folder = getPref($data_dir, $username, 'trash_folder');
+   if($trash_folder == '' || $trash_folder == 'none')
+      return;
 
    $now = time();
  
